@@ -1,7 +1,9 @@
 import argparse
+from pathlib import Path
 
-from src.duplicates import handle_duplicates
-from src.rename import rename_files
+from duplicates import handle_duplicates
+from rename import rename_files
+from settings import Settings
 
 
 def main():
@@ -17,11 +19,12 @@ def main():
     )
 
     args = parser.parse_args()
+    settings = Settings.from_file(Path(Path.cwd(), ".picorg", "settings.json"))
 
     if args.action == "rename":
         rename_files()
     elif args.action == "duplicates":
-        result = handle_duplicates()
+        result = handle_duplicates(settings.pic_paths)
         print(f"Found {len(result)} duplicates.")
 
 
